@@ -20,16 +20,18 @@ DATA <- Data
 Group <- rep(0, nrow(DATA))
 Group[gr == focal.name] <- 1  
 if (purify==FALSE) {
-STATS<-mantelHaenszel(DATA,Group,correct=correct)
+PROV <- mantelHaenszel(DATA,Group,correct=correct)
+STATS<-PROV$resMH
 if (max(STATS)<=qchisq(1-alpha,1)) DIFitems<-"No DIF item detected"
 else DIFitems <-(1:ncol(DATA))[STATS>qchisq(1-alpha,1)]
-RES <-list(MH=STATS,alpha=alpha,thr=qchisq(1-alpha,1),DIFitems=DIFitems,correct=correct,purification=purify,names=colnames(DATA))
+RES <-list(MH=STATS,alphaMH=PROV$resAlpha,alpha=alpha,thr=qchisq(1-alpha,1),DIFitems=DIFitems,correct=correct,purification=purify,names=colnames(DATA))
 }
 else{
 nrPur<-0
 difPur<-NULL
 noLoop<-FALSE
-stats1 <-mantelHaenszel(DATA,Group,correct=correct)
+prov1 <- mantelHaenszel(DATA,Group,correct=correct)
+stats1 <- prov1$resMH
 if (max(stats1)<=qchisq(1-alpha,1)) {
 DIFitems<-"No DIF item detected"
 noLoop<-TRUE
@@ -49,7 +51,8 @@ for (i in 1:ncol(DATA)){
 if (sum(i==dif)==0) nodif<-c(nodif,i)
 }
 }
-stats2 <-mantelHaenszel(DATA,Group,correct=correct,anchor=nodif)
+prov2 <- mantelHaenszel(DATA,Group,correct=correct,anchor=nodif)
+stats2 <- prov2$resMH
 if (max(stats2)<=qchisq(1-alpha,1)) dif2<-NULL
 else dif2<-(1:ncol(DATA))[stats2>qchisq(1-alpha,1)]
 difPur<-rbind(difPur,rep(0,ncol(DATA)))
@@ -67,6 +70,7 @@ else dif<-dif2
 }
 }
 stats1<-stats2
+prov1 <- prov2
 DIFitems <-(1:ncol(DATA))[stats1>qchisq(1-alpha,1)]
 }
 if (is.null(difPur)==FALSE){
@@ -76,7 +80,7 @@ for (ic in 1:ncol(difPur)) co[ic]<-paste("Item",ic,sep="")
 rownames(difPur)<-ro
 colnames(difPur)<-co
 }
-RES <-list(MH=stats1,alpha=alpha,thr=qchisq(1-alpha,1),DIFitems=DIFitems,correct=correct,purification=purify,nrPur=nrPur,difPur=difPur,convergence=noLoop,names=colnames(DATA))
+RES <-list(MH=stats1,alphaMH=prov1$resAlpha,alpha=alpha,thr=qchisq(1-alpha,1),DIFitems=DIFitems,correct=correct,purification=purify,nrPur=nrPur,difPur=difPur,convergence=noLoop,names=colnames(DATA))
 }
 class(RES) <-"MH"
 return(RES)
@@ -121,7 +125,7 @@ print.MH <- function(x, ...){
 }
  else cat("Convergence reached after ",res$nrPur,word,"\n","\n",sep="")
  }
- cat("Mantel-Haenszel statistic:","\n","\n")
+ cat("Mantel-Haenszel chi-square statistic:","\n","\n")
  pval <- round(1-pchisq(res$MH,1),4)
  symb <- symnum(pval,c(0,0.001,0.01,0.05,0.1,1),symbols=c("***","**","*",".",""))
  m1   <- cbind(round(res$MH,4),pval)
@@ -146,9 +150,34 @@ print.MH <- function(x, ...){
   print(m2, quote=FALSE)
   cat("\n","\n")
  }
+  cat("Effect size (ETS Delta scale):", "\n", "\n")
+  cat("Effect size code:", "\n")
+  cat(" '*': negligible effect", "\n")
+  cat(" '**': moderate effect", "\n")
+  cat(" '***': large effect", "\n", "\n")
+  r2 <- round(-2.35*log(res$alphaMH),4)
+  symb1 <- symnum(abs(r2), c(0, 1, 1.5, Inf), symbols = c("*", 
+      "**", "***"))
+  matR2<-cbind(round(res$alphaMH,4),r2)
+  matR2<- noquote(cbind(format(matR2, justify="right"), symb1))
+  if (is.null(res$names) == FALSE) 
+      rownames(matR2) <- res$names
+  else {
+      rn <- NULL
+      for (i in 1:nrow(matR2)) rn[i] <- paste("Item", i, sep = "")
+      rownames(matR2) <- rn
+  }
+  colnames(matR2) <- c("alphaMH", "deltaMH", "")
+  print(matR2)
+  cat("\n")
+  cat("Signif. codes: 0 '*' 1.0 '**' 1.5 '***'","\n")
+  cat(" (for absolute values of 'deltaMH')","\n")
 }
 
 
 
 
 
+
+
+
